==> subversion-1.4.0-arm-1.tgz: install/doinst.sh <==
( cd usr/lib ; rm -rf libsvn_subr-1.so.0 )
( cd usr/lib ; ln -sf libsvn_subr-1.so.0.0.0 libsvn_subr-1.so.0 )
( cd usr/lib ; rm -rf libsvn_subr-1.so )
( cd usr/lib ; ln -sf libsvn_subr-1.so.0.0.0 libsvn_subr-1.so )
( cd usr/lib ; rm -rf libsvn_delta-1.so.0 )
( cd usr/lib ; ln -sf libsvn_delta-1.so.0.0.0 libsvn_delta-1.so.0 )
( cd usr/lib ; rm -rf libsvn_delta-1.so )
( cd usr/lib ; ln -sf libsvn_delta-1.so.0.0.0 libsvn_delta-1.so )
( cd usr/lib ; rm -rf libsvn_fs_fs-1.so.0 )
( cd usr/lib ; ln -sf libsvn_fs_fs-1.so.0.0.0 libsvn_fs_fs-1.so.0 )
( cd usr/lib ; rm -rf libsvn_fs_fs-1.so )
( cd usr/lib ; ln -sf libsvn_fs_fs-1.so.0.0.0 libsvn_fs_fs-1.so )
( cd usr/lib ; rm -rf libsvn_fs_base-1.so.0 )
( cd usr/lib ; ln -sf libsvn_fs_base-1.so.0.0.0 libsvn_fs_base-1.so.0 )
( cd usr/lib ; rm -rf libsvn_fs_base-1.so )
( cd usr/lib ; ln -sf libsvn_fs_base-1.so.0.0.0 libsvn_fs_base-1.so )
( cd usr/lib ; rm -rf libsvn_fs-1.so.0 )
( cd usr/lib ; ln -sf libsvn_fs-1.so.0.0.0 libsvn_fs-1.so.0 )
( cd usr/lib ; rm -rf libsvn_fs-1.so )
( cd usr/lib ; ln -sf libsvn_fs-1.so.0.0.0 libsvn_fs-1.so )
( cd usr/lib ; rm -rf libsvn_ra_svn-1.so.0 )
( cd usr/lib ; ln -sf libsvn_ra_svn-1.so.0.0.0 libsvn_ra_svn-1.so.0 )
( cd usr/lib ; rm -rf libsvn_ra_svn-1.so )
( cd usr/lib ; ln -sf libsvn_ra_svn-1.so.0.0.0 libsvn_ra_svn-1.so )
( cd usr/lib ; rm -rf libsvn_repos-1.so.0 )
( cd usr/lib ; ln -sf libsvn_repos-1.so.0.0.0 libsvn_repos-1.so.0 )
( cd usr/lib ; rm -rf libsvn_repos-1.so )
( cd usr/lib ; ln -sf libsvn_repos-1.so.0.0.0 libsvn_repos-1.so )
( cd usr/lib ; rm -rf libsvn_ra_local-1.so.0 )
( cd usr/lib ; ln -sf libsvn_ra_local-1.so.0.0.0 libsvn_ra_local-1.so.0 )
( cd usr/lib ; rm -rf libsvn_ra_local-1.so )
( cd usr/lib ; ln -sf libsvn_ra_local-1.so.0.0.0 libsvn_ra_local-1.so )
( cd usr/lib ; rm -rf libsvn_ra_dav-1.so.0 )
( cd usr/lib ; ln -sf libsvn_ra_dav-1.so.0.0.0 libsvn_ra_dav-1.so.0 )
( cd usr/lib ; rm -rf libsvn_ra_dav-1.so )
( cd usr/lib ; ln -sf libsvn_ra_dav-1.so.0.0.0 libsvn_ra_dav-1.so )
( cd usr/lib ; rm -rf libsvn_diff-1.so.0 )
( cd usr/lib ; ln -sf libsvn_diff-1.so.0.0.0 libsvn_diff-1.so.0 )
( cd usr/lib ; rm -rf libsvn_diff-1.so )
( cd usr/lib ; ln -sf libsvn_diff-1.so.0.0.0 libsvn_diff-1.so )
( cd usr/lib ; rm -rf libsvn_ra-1.so.0 )
( cd usr/lib ; ln -sf libsvn_ra-1.so.0.0.0 libsvn_ra-1.so.0 )
( cd usr/lib ; rm -rf libsvn_ra-1.so )
( cd usr/lib ; ln -sf libsvn_ra-1.so.0.0.0 libsvn_ra-1.so )
( cd usr/lib ; rm -rf libsvn_wc-1.so.0 )
( cd usr/lib ; ln -sf libsvn_wc-1.so.0.0.0 libsvn_wc-1.so.0 )
( cd usr/lib ; rm -rf libsvn_wc-1.so )
( cd usr/lib ; ln -sf libsvn_wc-1.so.0.0.0 libsvn_wc-1.so )
( cd usr/lib ; rm -rf libsvn_client-1.so.0 )
( cd usr/lib ; ln -sf libsvn_client-1.so.0.0.0 libsvn_client-1.so.0 )
( cd usr/lib ; rm -rf libsvn_client-1.so )
( cd usr/lib ; ln -sf libsvn_client-1.so.0.0.0 libsvn_client-1.so )

==> subversion-1.5.4-arm-1.tgz: install/doinst.sh <==
( cd usr/lib ; rm -rf libsvn_ra_neon-1.so.0 )
( cd usr/lib ; ln -sf libsvn_ra_neon-1.so.0.0.0 libsvn_ra_neon-1.so.0 )
( cd usr/lib ; rm -rf libsvn_ra_neon-1.so )
( cd usr/lib ; ln -sf libsvn_ra_neon-1.so.0.0.0 libsvn_ra_neon-1.so )
( cd usr/lib ; rm -rf libsvn_ra-1.so )
( cd usr/lib ; ln -sf libsvn_ra-1.so.0.0.0 libsvn_ra-1.so )
( cd usr/lib ; rm -rf libsvn_subr-1.so )
( cd usr/lib ; ln -sf libsvn_subr-1.so.0.0.0 libsvn_subr-1.so )
( cd usr/lib ; rm -rf libsvn_ra_local-1.so.0 )
( cd usr/lib ; ln -sf libsvn_ra_local-1.so.0.0.0 libsvn_ra_local-1.so.0 )
( cd usr/lib ; rm -rf libsvn_ra_local-1.so )
( cd usr/lib ; ln -sf libsvn_ra_local-1.so.0.0.0 libsvn_ra_local-1.so )
( cd usr/lib ; rm -rf libsvn_wc-1.so )
( cd usr/lib ; ln -sf libsvn_wc-1.so.0.0.0 libsvn_wc-1.so )
( cd usr/lib ; rm -rf libsvn_fs-1.so )
( cd usr/lib ; ln -sf libsvn_fs-1.so.0.0.0 libsvn_fs-1.so )
( cd usr/lib ; rm -rf libsvn_fs_fs-1.so.0 )
( cd usr/lib ; ln -sf libsvn_fs_fs-1.so.0.0.0 libsvn_fs_fs-1.so.0 )
( cd usr/lib ; rm -rf libsvn_diff-1.so.0 )
( cd usr/lib ; ln -sf libsvn_diff-1.so.0.0.0 libsvn_diff-1.so.0 )
( cd usr/lib ; rm -rf libsvn_fs_util-1.so.0 )
( cd usr/lib ; ln -sf libsvn_fs_util-1.so.0.0.0 libsvn_fs_util-1.so.0 )
( cd usr/lib ; rm -rf libsvn_fs_util-1.so )
( cd usr/lib ; ln -sf libsvn_fs_util-1.so.0.0.0 libsvn_fs_util-1.so )
( cd usr/lib ; rm -rf libsvn_wc-1.so.0 )
( cd usr/lib ; ln -sf libsvn_wc-1.so.0.0.0 libsvn_wc-1.so.0 )
( cd usr/lib ; rm -rf libsvn_ra_svn-1.so )
( cd usr/lib ; ln -sf libsvn_ra_svn-1.so.0.0.0 libsvn_ra_svn-1.so )
( cd usr/lib ; rm -rf libsvn_repos-1.so.0 )
( cd usr/lib ; ln -sf libsvn_repos-1.so.0.0.0 libsvn_repos-1.so.0 )
( cd usr/lib ; rm -rf libsvn_repos-1.so )
( cd usr/lib ; ln -sf libsvn_repos-1.so.0.0.0 libsvn_repos-1.so )
( cd usr/lib ; rm -rf libsvn_fs-1.so.0 )
( cd usr/lib ; ln -sf libsvn_fs-1.so.0.0.0 libsvn_fs-1.so.0 )
( cd usr/lib ; rm -rf libsvn_fs_base-1.so )
( cd usr/lib ; ln -sf libsvn_fs_base-1.so.0.0.0 libsvn_fs_base-1.so )
( cd usr/lib ; rm -rf libsvn_ra-1.so.0 )
( cd usr/lib ; ln -sf libsvn_ra-1.so.0.0.0 libsvn_ra-1.so.0 )
( cd usr/lib ; rm -rf libsvn_delta-1.so )
( cd usr/lib ; ln -sf libsvn_delta-1.so.0.0.0 libsvn_delta-1.so )
( cd usr/lib ; rm -rf libsvn_client-1.so )
( cd usr/lib ; ln -sf libsvn_client-1.so.0.0.0 libsvn_client-1.so )
( cd usr/lib ; rm -rf libsvn_fs_fs-1.so )
( cd usr/lib ; ln -sf libsvn_fs_fs-1.so.0.0.0 libsvn_fs_fs-1.so )
( cd usr/lib ; rm -rf libsvn_diff-1.so )
( cd usr/lib ; ln -sf libsvn_diff-1.so.0.0.0 libsvn_diff-1.so )
( cd usr/lib ; rm -rf libsvn_ra_svn-1.so.0 )
( cd usr/lib ; ln -sf libsvn_ra_svn-1.so.0.0.0 libsvn_ra_svn-1.so.0 )
( cd usr/lib ; rm -rf libsvn_fs_base-1.so.0 )
( cd usr/lib ; ln -sf libsvn_fs_base-1.so.0.0.0 libsvn_fs_base-1.so.0 )
( cd usr/lib ; rm -rf libsvn_client-1.so.0 )
( cd usr/lib ; ln -sf libsvn_client-1.so.0.0.0 libsvn_client-1.so.0 )
( cd usr/lib ; rm -rf libsvn_subr-1.so.0 )
( cd usr/lib ; ln -sf libsvn_subr-1.so.0.0.0 libsvn_subr-1.so.0 )
( cd usr/lib ; rm -rf libsvn_delta-1.so.0 )
( cd usr/lib ; ln -sf libsvn_delta-1.so.0.0.0 libsvn_delta-1.so.0 )
